@@ -1473,15 +1473,11 @@ dict_create_index_step(
 	}
 
 	if (node->state == INDEX_ADD_TO_CACHE) {
-
-		index_id_t	index_id = node->index->id;
-
 		err = dict_index_add_to_cache(
 			node->table, node->index, FIL_NULL,
 			trx_is_strict(trx), node->add_v);
 
-		node->index = dict_index_get_if_in_cache_low(index_id);
-		ut_a((node->index == NULL) == (err != DB_SUCCESS));
+		ut_ad((node->index == NULL) == (err != DB_SUCCESS));
 
 		if (err != DB_SUCCESS) {
 
