@@ -1087,23 +1087,6 @@ dict_make_room_in_cache(
 
 #define BIG_ROW_SIZE	1024
 
-/** Adds an index to the dictionary cache.
-@param[in]	table	table on which the index is
-@param[in]	index	index; NOTE! The index memory
-			object is freed in this function!
-@param[in]	page_no	root page number of the index
-@param[in]	strict	TRUE=refuse to create the index
-			if records could be too big to fit in
-			an B-tree page
-@return DB_SUCCESS, DB_TOO_BIG_RECORD, or DB_CORRUPTION */
-dberr_t
-dict_index_add_to_cache(
-	dict_table_t*	table,
-	dict_index_t*	index,
-	ulint		page_no,
-	ibool		strict)
-	MY_ATTRIBUTE((warn_unused_result));
-
 /** Clears the virtual column's index list before index is being freed.
 @param[in]  index   Index being freed */
 void
@@ -1112,23 +1095,22 @@ dict_index_remove_from_v_col_list(
 
 /** Adds an index to the dictionary cache, with possible indexing newly
 added column.
-@param[in]	table	table on which the index is
-@param[in]	index	index; NOTE! The index memory
+@param[in,out]	table	table on which the index is
+@param[in,out]	index	index; NOTE! The index memory
 			object is freed in this function!
-@param[in]	add_v	new virtual column that being added along with
-			an add index call
 @param[in]	page_no	root page number of the index
-@param[in]	strict	TRUE=refuse to create the index
+@param[in]	strict	true=refuse to create the index
 			if records could be too big to fit in
 			an B-tree page
+@param[in]	add_v	virtual columns being added along with ADD INDEX
 @return DB_SUCCESS, DB_TOO_BIG_RECORD, or DB_CORRUPTION */
 dberr_t
-dict_index_add_to_cache_w_vcol(
+dict_index_add_to_cache(
 	dict_table_t*		table,
-	dict_index_t*		index,
-	const dict_add_v_col_t* add_v,
+	dict_index_t*&		index,
 	ulint			page_no,
-	ibool			strict)
+	bool			strict = false,
+	const dict_add_v_col_t* add_v = NULL)
 	MY_ATTRIBUTE((warn_unused_result));
 /********************************************************************//**
 Gets the number of fields in the internal representation of an index,
